import logging
import win32serviceutil  # type: ignore
import servicemanager    # type: ignore
import win32event        # type: ignore
import win32service      # type: ignore

import jetpack.util
import jetpack.service

logger = logging.getLogger(__name__)


class JetpackService(win32serviceutil.ServiceFramework):
    _svc_name_ = 'jetpackd'
    _svc_display_name_ = 'CycleCloud Jetpack'
    _svc_description_ = 'The CycleCloud Jetpack service handles background tasks required for nodes to be part of a CycleCloud cluster.'

    @classmethod
    def parse_command_line(cls):
        win32serviceutil.HandleCommandLine(cls)

    def __init__(self, args):
        win32serviceutil.ServiceFramework.__init__(self, args)
        self.hWaitStop = win32event.CreateEvent(None, 0, 0, None)
        self.is_alive = True

    def SvcStop(self):
        self.ReportServiceStatus(win32service.SERVICE_STOP_PENDING)
        win32event.SetEvent(self.hWaitStop)
        self.is_alive = False

    def SvcDoRun(self):
        servicemanager.LogMsg(servicemanager.EVENTLOG_INFORMATION_TYPE, servicemanager.PYS_SERVICE_STARTED, (self._svc_name_, ''))
        jetpack.service.initialize()
        while self.is_alive:
            jetpack.service.main()

        