import os
from jetpack.util import command

# pylint: disable=missing-function-docstring

def test_prepare_dir(tmp_path):
    now = 1000000000.0

    timestamp = now
    timestamp = _write(tmp_path / "file1", timestamp)
    timestamp = _write(tmp_path / "file2", timestamp)
    timestamp = _write(tmp_path / "file3", timestamp)
    timestamp = _write(tmp_path / "file4", timestamp)

    assert ["file1", "file2", "file3", "file4"] == _get_files(tmp_path)

    # deletes the oldest file
    command.prepare_dir(tmp_path, now, cutoff=86400, max_files=2)
    assert ["file3", "file4"] == _get_files(tmp_path)

def test_linux_get_env_var():
    runner = command.LinuxCommandRunner()
    assert "export VAR=VALUE\n" == runner.get_env_var("VAR", "VALUE")
    assert "export VAR='COMPLEX VALUE'\n" == runner.get_env_var("VAR", "COMPLEX VALUE")

def test_windows_get_env_var():
    runner = command.WindowsCommandRunner()
    assert 'SET "VAR=VALUE"\n' == runner.get_env_var("VAR", "VALUE")
    assert 'SET "VAR=COMPLEX VALUE"\n' == runner.get_env_var("VAR", "COMPLEX VALUE")

def test_linux_get_comment():
    runner = command.LinuxCommandRunner()
    assert '# Comment here' == runner.get_comment("Comment here")

def test_windows_get_comment():
    runner = command.WindowsCommandRunner()
    assert 'REM Comment here' == runner.get_comment("Comment here")

def test_linux_create_script():
    runner = command.LinuxCommandRunner()
    script = runner.get_script_contents(["some_command", "foo bar"])

    assert "some_command 'foo bar'" in script

def test_windows_create_script():
    runner = command.WindowsCommandRunner()
    script = runner.get_script_contents(["some_command", "foo bar"])

    assert "\"some_command\" \"foo bar\"" in script

def _write(file, timestamp:float):
    with open(file, "w", encoding="utf-8") as f:
        f.write("")
    os.utime(file, (timestamp, timestamp))
    return timestamp + 1

def _get_files(path):
    files = list(os.listdir(path))
    files.sort(key=lambda f: os.path.getmtime(os.path.join(path / f)))
    return files
